@@ -3,7 +3,7 @@
  *
  *  Copyright (C) Gerhard Monzel - November 2001
  *
- *  This file is part of transcode, a linux video stream processing tool
+ *  This file is part of transcode, a video stream processing tool
  *      
  *  transcode is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -24,31 +24,15 @@
 #define MOD_NAME    "filter_dnr.so"
 #define MOD_VERSION "v0.2 (2003-01-21)"
 #define MOD_CAP     "dynamic noise reduction"
-
-#include <stdio.h>
-#include <stdlib.h>
-#include <sys/stat.h>
-#include <unistd.h>
-
-/* -------------------------------------------------
- *
- * mandatory include files
- *
- *-------------------------------------------------*/
-
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
-#include <unistd.h>
-#include <inttypes.h>
-#include <stdio.h>
-#include <math.h>
-#include <string.h>
+#define MOD_AUTHOR  "Gerhard Monzel"
 
 #include "transcode.h"
-#include "framebuffer.h"
+#include "filter.h"
 #include "optstr.h"
 
+#include <math.h>
+
+
 typedef unsigned char T_PIXEL;
 
 typedef struct t_dnr_filter_ctx 
